====================
awesome-slugify
====================

**A Python slugify package**

install
==================
    pip install awesome-slugify

use
=================
    from slugify import slugify

    >>> slugify('Nín hǎo. Wǒ shì zhōng guó rén')
    u'nin-hao-wo-shi-zhong-guo-ren'